@@ -80,8 +80,9 @@ def sanitize_data(data: dict):
 
 def adapter_data(*, start_time, end_time, request=None, response=None, method=None, url=None):
     trace_id = request.headers.get("X-Olympus-Traceid", None)
+    flow_id = os.environ.get("FLOW_ID", None)
 
-    if trace_id is not None:
+    if trace_id is not None and flow_id is not None:
         if response.status_code >= 500:
             flag = 3
         else:
@@ -95,7 +96,6 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
 
         test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
         flow_probe_name = (test_name.split(":")[0].split(".")[0].replace("tests_", "").replace("test_", "").replace("_", " ").title())
-        flow_id = os.environ.get("FLOW_ID")
         status_code = response.status_code
         trace_name = request.method
         duration = end_time - start_time
